==> linuxconf-1.33r3.src.tar.gz: linuxconf-1.33r3/fstab/fstab.pm <==
/* _dict.cc 14/08/1996 15.13.30 */
/* fixperm.cc 13/06/2001 10.43.36 */
PRIVATE void FIXPERM_SPEC::parsedev (SPEC_ONE&sp);
PUBLIC FIXPERM_SPEC::FIXPERM_SPEC (SPEC_ONE&sp);
PUBLIC int FIXPERM_SPEC::create (PERMINFO&p);
PUBLIC int FIXPERM_SPEC::check (void);
PRIVATE void FIXPERM_SPECS::addline (const char *buf, SPEC_ONE&sp);
PUBLIC void FIXPERM_SPECS::addline (const char *buf);
PUBLIC int FIXPERM_SPECS::readspecf (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (void);
PUBLIC FIXPERM_SPEC *FIXPERM_SPECS::getitem (int no);
PUBLIC int FIXPERM_SPECS::check (bool boottime, bool silentflag);
PUBLIC int FIXPERM_SPECS::check (void);
PUBLIC FIXPERM_TASK::FIXPERM_TASK (void);
PUBLIC int FIXPERM_SPEC::edit (void);
/* fstab1.cc 03/01/2002 11.20.22 */
PUBLIC CONFIG_FILE_FSTAB::CONFIG_FILE_FSTAB (const char *_path,
	 bool _local,
	 const char *subsys);
PRIVATE void CONFIG_FILE_FSTAB::walk_do (FSTAB&fs,
	 bool del,
	 SSTREAM *ss)const;
PUBLIC int CONFIG_FILE_FSTAB::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_FSTAB::extract (SSTREAM&ss);
PRIVATE void FSTAB_ENTRY::init (void);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (void);
PUBLIC void FSTAB_ENTRY::parseopt (char *opts);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (const char *line);
PUBLIC void FSTAB_ENTRY::format_opt (bool tosave, char *str)const;
PUBLIC void FSTAB_ENTRY::print (SSTREAM&ss)const;
PUBLIC int FSTAB_ENTRY::is_valid (void)const;
PUBLIC int FSTAB_ENTRY::is_auto (void);
PUBLIC int FSTAB_ENTRY::is_remote (void)const;
PUBLIC int FSTAB_ENTRY::is_swap (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_u (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_g (void)const;
PUBLIC FSTAB_ENTRY_TYPE FSTAB_ENTRY::gettype (void)const;
PUBLIC const char *FSTAB_ENTRY::getfs (void)const;
PUBLIC const char *FSTAB_ENTRY::getsource (void)const;
PUBLIC void FSTAB_ENTRY::setsource (const char *path);
PUBLIC const char *FSTAB_ENTRY::getmpoint (void)const;
PUBLIC const char *FSTAB_ENTRY::getcomment (void);
PUBLIC FSTAB::FSTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::getitem (int no);
PUBLIC int FSTAB::write (void);
/* fstab2.cc 18/09/2001 22.29.24 */
PUBLIC int FSTAB_ENTRY::umount_control (void);
PUBLIC int FSTAB_ENTRY::mount_control (void);
PUBLIC int FSTAB_ENTRY::edit (FSTAB_ENTRY_TYPE fstype);
PRIVATE int FSTAB::setmenu (DIALOG_LISTE&dia,
	 FSTAB_ENTRY_TYPE fstype,
	 FSTAB_ENTRY *tbsel[]);
PUBLIC void FSTAB::edit (FSTAB_ENTRY_TYPE fstype);
PUBLIC void FSTAB::control (FSTAB_ENTRY_TYPE fstype);
/* fstab3.cc 22/10/2003 15.33.52 */
PRIVATE void FSTAB::fixroot (FSTAB_ENTRY *root, char *status);
PUBLIC int FSTAB_ENTRY::check (void);
PUBLIC const char *FSTAB::getrootdev (void);
PUBLIC void FSTAB::check (void);
/* fstab.cc 22/10/2003 15.21.36 */
/* helpf.cc 14/08/1996 15.14.30 */
PUBLIC FSTAB_HELP_FILE::FSTAB_HELP_FILE (const char *fname);
/* mtab.cc 22/10/2003 15.31.52 */
PUBLIC MTAB::MTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_mpoint (const char *str);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_source (const char *str);
PUBLIC int FSTAB_ENTRY::domount (void);
PUBLIC int FSTAB_ENTRY::doumount (void);
PUBLIC bool FSTAB_ENTRY::is_mounted (void);
/* nfs.cc 26/05/1995 12.41.58 */
/* partition.cc 30/01/2002 16.43.14 */
PUBLIC PARTITION::PARTITION (const char *_dev,
	 int _id,
	 long _size,
	 const char *_mpoint);
PUBLIC PARTITION::~PARTITION (void);
PUBLIC void PARTITION::setdosdrive (char letter);
PUBLIC char PARTITION::getdosdrive (void);
PUBLIC int PARTITION::isdos (void);
PUBLIC int PARTITION::isos2 (void);
PUBLIC int PARTITION::isswap (void);
PUBLIC int PARTITION::islinux (void);
PUBLIC const char *PARTITION::getdevice (void);
PUBLIC long PARTITION::getsize (void);
PUBLIC int PARTITION::getid (void);
PUBLIC void PARTITION::formatinfo (char *buf, bool show_mount);
PUBLIC const char *PARTITION::getos (void);
PUBLIC int PARTITION::readlabel (SSTRING&s);
PUBLIC int PARTITIONS::load (void);
PUBLIC PARTITION *PARTITIONS::getitem (int no)const;
PUBLIC PARTITION *PARTITIONS::getitem (const char *device)const;
PROTECTED void PARTITIONS::setdosdrive (void);
PUBLIC PARTITIONS::PARTITIONS (void);

==> linuxconf-1.34r3.src.tar.gz: linuxconf-1.34r3/fstab/fstab.pm <==
/* _dict.cc 14/08/1996 15.13.30 */
/* fixperm.cc 13/06/2001 10.43.36 */
PRIVATE void FIXPERM_SPEC::parsedev (SPEC_ONE&sp);
PUBLIC FIXPERM_SPEC::FIXPERM_SPEC (SPEC_ONE&sp);
PUBLIC int FIXPERM_SPEC::create (PERMINFO&p);
PUBLIC int FIXPERM_SPEC::check (void);
PRIVATE void FIXPERM_SPECS::addline (const char *buf, SPEC_ONE&sp);
PUBLIC void FIXPERM_SPECS::addline (const char *buf);
PUBLIC int FIXPERM_SPECS::readspecf (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (const char *fname);
PUBLIC FIXPERM_SPECS::FIXPERM_SPECS (void);
PUBLIC FIXPERM_SPEC *FIXPERM_SPECS::getitem (int no);
PUBLIC int FIXPERM_SPECS::check (bool boottime, bool silentflag);
PUBLIC int FIXPERM_SPECS::check (void);
PUBLIC FIXPERM_TASK::FIXPERM_TASK (void);
PUBLIC int FIXPERM_SPEC::edit (void);
/* fstab1.cc 31/08/2004 17.00.32 */
PUBLIC CONFIG_FILE_FSTAB::CONFIG_FILE_FSTAB (const char *_path,
	 bool _local,
	 const char *subsys);
PRIVATE void CONFIG_FILE_FSTAB::walk_do (FSTAB&fs,
	 bool del,
	 SSTREAM *ss)const;
PUBLIC int CONFIG_FILE_FSTAB::archive (SSTREAM&ss)const;
PUBLIC int CONFIG_FILE_FSTAB::extract (SSTREAM&ss);
PRIVATE void FSTAB_ENTRY::init (void);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (void);
PUBLIC void FSTAB_ENTRY::parseopt (char *opts);
PUBLIC FSTAB_ENTRY::FSTAB_ENTRY (const char *line);
PUBLIC void FSTAB_ENTRY::format_opt (bool tosave, char *str)const;
PUBLIC void FSTAB_ENTRY::print (SSTREAM&ss)const;
PUBLIC int FSTAB_ENTRY::is_valid (void)const;
PUBLIC int FSTAB_ENTRY::is_auto (void);
PUBLIC int FSTAB_ENTRY::is_remote (void)const;
PUBLIC int FSTAB_ENTRY::is_swap (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_u (void)const;
PUBLIC bool FSTAB_ENTRY::has_quota_g (void)const;
PUBLIC FSTAB_ENTRY_TYPE FSTAB_ENTRY::gettype (void)const;
PUBLIC const char *FSTAB_ENTRY::getfs (void)const;
PUBLIC const char *FSTAB_ENTRY::getsource (void)const;
PUBLIC void FSTAB_ENTRY::setsource (const char *path);
PUBLIC const char *FSTAB_ENTRY::getmpoint (void)const;
PUBLIC bool FSTAB_ENTRY::getloop (SSTRING&dev);
PUBLIC void FSTAB_ENTRY::setloop (bool on, const char *dev);
PUBLIC const char *FSTAB_ENTRY::getcomment (void);
PUBLIC FSTAB::FSTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::getitem (int no);
PUBLIC int FSTAB::write (void);
/* fstab3.cc 22/10/2003 15.33.52 */
PRIVATE void FSTAB::fixroot (FSTAB_ENTRY *root, char *status);
PUBLIC int FSTAB_ENTRY::check (void);
PUBLIC const char *FSTAB::getrootdev (void);
PUBLIC void FSTAB::check (void);
/* fstab.cc 22/10/2003 15.21.36 */
/* helpf.cc 14/08/1996 15.14.30 */
PUBLIC FSTAB_HELP_FILE::FSTAB_HELP_FILE (const char *fname);
/* mtab.cc 31/08/2004 17.00.24 */
PUBLIC MTAB::MTAB (void);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_mpoint (const char *str);
PUBLIC FSTAB_ENTRY *FSTAB_GEN::locate_source (const char *str);
PUBLIC int FSTAB_ENTRY::domount (void);
PUBLIC int FSTAB_ENTRY::doumount (void);
PUBLIC bool FSTAB_ENTRY::is_mounted (void);
/* nfs.cc 26/05/1995 12.41.58 */
/* partition.cc 31/08/2004 16.12.32 */
PUBLIC PARTITION::PARTITION (const char *_dev,
	 int _id,
	 long _size,
	 const char *_mpoint);
PUBLIC PARTITION::~PARTITION (void);
PUBLIC void PARTITION::setdosdrive (char letter);
PUBLIC char PARTITION::getdosdrive (void);
PUBLIC int PARTITION::isdos (void);
PUBLIC int PARTITION::isos2 (void);
PUBLIC int PARTITION::isswap (void);
PUBLIC int PARTITION::islinux (void);
PUBLIC const char *PARTITION::getdevice (void);
PUBLIC long PARTITION::getsize (void);
PUBLIC int PARTITION::getid (void);
PUBLIC void PARTITION::formatinfo (SSTRING&buf, bool show_mount);
PUBLIC const char *PARTITION::getos (void);
PUBLIC int PARTITION::readlabel (SSTRING&s);
PUBLIC int PARTITIONS::load (void);
PUBLIC PARTITION *PARTITIONS::getitem (int no)const;
PUBLIC PARTITION *PARTITIONS::getitem (const char *device)const;
PROTECTED void PARTITIONS::setdosdrive (void);
PUBLIC PARTITIONS::PARTITIONS (void);
/* fstab2.tlcc 31/08/2004 17.00.36 */
PUBLIC int FSTAB_ENTRY::umount_control (void);
PUBLIC int FSTAB_ENTRY::mount_control (void);
PUBLIC int FSTAB_ENTRY::edit (FSTAB_ENTRY_TYPE fstype);
void _F_fstabsel::add (void);
PUBLIC void FSTAB::edit (FSTAB_ENTRY_TYPE fstype);
PUBLIC void FSTAB::control (FSTAB_ENTRY_TYPE fstype);
